@@ -1,6 +1,6 @@
 #ifndef lint
 static char Rcs_Id[] =
-    "$Id: defmt.c,v 1.39 1995/01/08 23:23:54 geoff Exp $";
+    "$Id: defmt.c,v 1.41 1995/08/05 23:19:47 geoff Exp $";
 #endif
 
 /*
@@ -54,6 +54,16 @@ static char Rcs_Id[] =
 
 /*
  * $Log: defmt.c,v $
+ * Revision 1.41  1995/08/05  23:19:47  geoff
+ * Get rid of an obsolete comment.  Add recognition of documentclass and
+ * usepackage for Latex2e support.
+ *
+ * Revision 1.40  1995/03/06  02:42:43  geoff
+ * Change TeX backslash processing so that it only assumes alpha
+ * characters and the commonly-used "@" character are part of macro
+ * names, and so that any other backslashed character (specifically
+ * dollar signs) is skipped.
+ *
  * Revision 1.39  1995/01/08  23:23:54  geoff
  * Fix typos in a couple of comments.
  *
@@ -591,14 +601,14 @@ static int TeX_math_begin (bufp)
     while (**bufp == TEXBACKSLASH)
 	{
 	(*bufp)++; /* check for null char here? */
-	if (**bufp == TEXBACKSLASH)
+	if (**bufp == TEXLEFTPAREN  ||  **bufp == TEXLEFTSQUARE)
+	    return 1;
+	else if (!isalpha(**bufp)  &&  **bufp != '@')
 	    {
 	    (*bufp)++;
 	    continue;
 	    }
-	if (**bufp == TEXLEFTPAREN  ||  **bufp == TEXLEFTSQUARE)
-	    return 1;
-	if (TeX_strncmp (*bufp, "begin", 5) == 0)
+	else if (TeX_strncmp (*bufp, "begin", 5) == 0)
 	    {
 	    if (TeX_math_check ('b', bufp))
 		return 1;
@@ -787,16 +797,8 @@ static void TeX_open_paren (bufp)
 static void TeX_skip_check (bufp)
     char **	bufp;
     {
-    int		charlen;
     int		skip_ch;
 
-    /* ADDITIONALLY, MAY WANT TO ADD:
-     * documentstyle, pagestyle, pagenumbering
-     * WITH TWO {} {}'S TO SKIP:
-     * setcounter, addtocounter,
-     * setlength, addtolength, settowidth
-     */
-
     if (TeX_strncmp(*bufp, "end", 3) == 0
       ||  TeX_strncmp(*bufp, "vspace", 6) == 0
       ||  TeX_strncmp(*bufp, "hspace", 6) == 0
@@ -809,6 +811,8 @@ static void TeX_skip_check (bufp)
       ||  TeX_strncmp(*bufp, "include", 7) == 0
       ||  TeX_strncmp(*bufp, "includeonly", 11) == 0
       ||  TeX_strncmp(*bufp, "documentstyle", 13) == 0
+      ||  TeX_strncmp(*bufp, "documentclass", 13) == 0
+      ||  TeX_strncmp(*bufp, "usepackage", 10) == 0
       ||  TeX_strncmp(*bufp, "pagestyle", 9) == 0
       ||  TeX_strncmp(*bufp, "pagenumbering", 13) == 0
 #ifndef IGNOREBIB
@@ -858,15 +862,8 @@ static void TeX_skip_check (bufp)
 	*/
 
 	/* Must look at the space after the command. */
-	while (**bufp
-	  && (l1_isstringch (*bufp, charlen, 0)
-	    ||  iswordch (chartoichar (**bufp))))
-	    {
-	    if (!isstringch (*bufp + charlen, 0)
-	      &&  !iswordch (chartoichar ((*bufp)[charlen])))
-		break;
-	    *bufp += charlen;
-	    }
+	while (isalpha(**bufp)  ||  **bufp == '@')
+	    (*bufp)++;
 	/*
 	** Our caller expects to skip over a single character.  So we
 	** need to back up by one.  Ugh.
