@@ -1,7 +1,6 @@
-/* -*- Mode: Text -*- */
 #ifndef lint
 static char Rcs_Id[] =
-    "$Id: icombine.c,v 2.13 91/07/15 19:55:02 geoff Exp $";
+    "$Id: icombine.c,v 2.24 1994/01/25 07:11:35 geoff Exp $";
 #endif
 
 #define MAIN
@@ -16,81 +15,68 @@ static char Rcs_Id[] =
  * to buildhash and ispell, we can be sure that the rules for combining
  * capitalizations are compatible.
  *
- * Copyright 1988, 1989, by Geoff Kuenning, Manhattan Beach, CA
- * Permission for non-profit use is hereby granted.
- * All other rights reserved.
- * See "version.h" for a more complete copyright notice.
+ * Copyright 1992, 1993, Geoff Kuenning, Granada Hills, CA
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ *
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * 3. All modifications to the source code must be clearly marked as
+ *    such.  Binary redistributions based on modified source code
+ *    must be clearly marked as modified versions in the documentation
+ *    and/or other materials provided with the distribution.
+ * 4. All advertising materials mentioning features or use of this software
+ *    must display the following acknowledgment:
+ *      This product includes software developed by Geoff Kuenning and
+ *      other unpaid contributors.
+ * 5. The name of Geoff Kuenning may not be used to endorse or promote
+ *    products derived from this software without specific prior
+ *    written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY GEOFF KUENNING AND CONTRIBUTORS ``AS IS'' AND
+ * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED.  IN NO EVENT SHALL GEOFF KUENNING OR CONTRIBUTORS BE LIABLE
+ * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+ * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
+ * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+ * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+ * SUCH DAMAGE.
  */
 
 /*
- * $Log:	icombine.c,v $
- * Revision 2.13  91/07/15  19:55:02  geoff
- * Make sure the argument to makedent is properly converted to canonical form.
- * 
- * Revision 2.12  91/07/15  19:26:52  geoff
- * Provide the "canonical" parameter to all strtoichar calls.
- * 
- * Revision 2.11  91/07/11  19:52:08  geoff
- * Remove the include of stdio.h, since ispell.h now does this.
- * 
- * Revision 2.10  91/07/04  00:04:09  geoff
- * Add the "-T" switch to support conversion between different stringchar
- * standards.
- * 
- * Revision 2.9  91/07/03  18:20:39  geoff
- * Don't include types.h, dir.h, or param.h, since config.h now does that.
- * 
- * Revision 2.8  91/06/23  22:01:03  geoff
- * On non-USG systems, include sys/dir.h for MAXNAMLEN
- * 
- * Revision 2.7  90/12/31  01:04:06  geoff
- * Reformat to follow a consistent convention throughout ispell.
- * 
- * Revision 2.6  89/06/09  15:53:14  geoff
- * Add support for the internal "character" type, ichar_t.
- * 
- * Revision 2.5  89/04/28  01:08:51  geoff
- * Change Header to Id;  nobody cares about my pathnames.
- * 
- * Revision 2.4  89/04/03  01:55:26  geoff
- * Fix some lint complaints.
- * 
- * Revision 2.3  88/12/26  02:26:01  geoff
- * Update the copyright notice.
- * 
- * Revision 2.2  88/11/25  19:50:46  geoff
- * Get rid of some unused variables.  Add proper casts in two calls to
- * myfree.
- * 
- * Revision 2.1  88/04/30  22:12:31  geoff
- * Fix some lint complaints.
- * 
- * Revision 2.0  88/03/26  23:20:57  geoff
- * Complete rewrite making use of code from buildhash.c
- * 
+ * $Log: icombine.c,v $
+ * Revision 2.24  1994/01/25  07:11:35  geoff
+ * Get rid of all old RCS log lines in preparation for the 3.1 release.
+ *
  */
 
 #include <ctype.h>
 #include "config.h"
 #include "ispell.h"
+#include "proto.h"
 #include "msgs.h"
 
 char *		Lfile;			/* Language-description file */
 
-extern char *	index ();
-extern char *	malloc ();
-extern char *	realloc ();
-extern void	free ();
-extern char *	strcpy ();
-extern void	exit ();
+int		main P ((int argc, char * argv[]));
+static void	usage P ((void));
+VOID *		mymalloc P ((unsigned int size));
+VOID *		myrealloc P ((VOID * ptr, unsigned int size,
+		  unsigned int oldsize));
+void		myfree P ((VOID * ptr));
+static void	combinedict P ((void));
+static void	combineout P ((void));
 
-extern void yyinit();
-extern void upcase();
-#ifdef CAPITALIZATION
-extern long whatcap();
-#endif
-
-main (argc, argv)
+int main (argc, argv)
     int		argc;
     char *	argv[];
     {
@@ -133,7 +119,7 @@ main (argc, argv)
 
     if (preftype != NULL)
 	{
-	defdupchar = findfiletype (preftype, 1);
+	defdupchar = findfiletype (preftype, 1, (int *) NULL);
 	if (defdupchar < 0
 	  &&  strcmp (preftype, "tex") != 0
 	  &&  strcmp (preftype, "nroff") != 0)
@@ -150,35 +136,36 @@ main (argc, argv)
     return 0;
     }
 
-usage ()
+static void usage ()
     {
 
     (void) fprintf (stderr, ICOMBINE_C_USAGE);
     exit (1);
     }
 
-char * mymalloc (size)
-    int		size;
+VOID * mymalloc (size)
+    unsigned int	size;
     {
-    return malloc ((unsigned) size);
+    return malloc (size);
     }
 
 /* ARGSUSED */
-char * myrealloc (ptr, size, oldsize)
-    char *	ptr;
-    int		size;
-    int		oldsize;
+VOID * myrealloc (ptr, size, oldsize)
+    VOID *		ptr;
+    unsigned int	size;
+    unsigned int	oldsize;
     {
-    return realloc (ptr, (unsigned) size);
+
+    return realloc (ptr, size);
     }
 
 void myfree (ptr)
-    char *	ptr;
+    VOID *	ptr;
     {
     free (ptr);
     }
 
-combinedict ()
+static void combinedict ()
     {
     struct dent		d;
     register struct dent * dp;
@@ -192,10 +179,15 @@ combinedict ()
     hashtbl->word = 0;
     while (fgets (lbuf, sizeof lbuf, stdin) != NULL)
 	{
-	if (makedent (ichartosstr (strtosichar (lbuf, 0), 1), &d) < 0)
+	if (ichartostr (lbuf, strtosichar (lbuf, 0), sizeof lbuf, 1))
+	    (void) fprintf (stderr, WORD_TOO_LONG (lbuf));
+	if (makedent (ichartosstr (strtosichar (lbuf, 0), 1),
+	    ICHARTOSSTR_SIZE, &d)
+	  < 0)
 	    continue;
 
-	strtoichar (ucbuf, d.word, 1);
+	if (strtoichar (ucbuf, d.word, sizeof ucbuf, 1))
+	    (void) fprintf (stderr, WORD_TOO_LONG (lbuf));
 	upcase (ucbuf);
 	if (icharcmp (ucbuf, lastbuf) != 0)
 	    {
@@ -210,7 +202,7 @@ combinedict ()
 	if ((dp->flagfield & USED) == 0)
 	    {
 	    *dp = d;
-#ifdef CAPITALIZATION
+#ifndef NO_CAPITALIZATION_SUPPORT
 	    /*
 	    ** If it's a followcase word, we need to make this a
 	    ** special dummy entry, and add a second with the
@@ -236,7 +228,7 @@ combinedict ()
     combineout ();
     }
 
-combineout ()
+static void combineout ()
     {
     register struct dent *	ndp;
     register struct dent *	tdp;
@@ -252,7 +244,7 @@ combineout ()
 	    toutent (stdout, tdp, 0);
 	    myfree (tdp->word);
 	    ndp = tdp->next;
-#ifdef CAPITALIZATION
+#ifndef NO_CAPITALIZATION_SUPPORT
 	    while (tdp->flagfield & MOREVARIANTS)
 		{
 		if (tdp != hashtbl)
