@@ -1,6 +1,6 @@
 #ifndef lint
 static char Rcs_Id[] =
-    "$Id: ispell.c,v 1.131 1995/01/08 23:23:39 geoff Exp $";
+    "$Id: ispell.c,v 1.133 1995/10/11 04:30:29 geoff Exp $";
 #endif
 
 #define MAIN
@@ -49,6 +49,13 @@ static char Rcs_Id[] =
 
 /*
  * $Log: ispell.c,v $
+ * Revision 1.133  1995/10/11  04:30:29  geoff
+ * Get rid of an unused variable.
+ *
+ * Revision 1.132  1995/08/05  23:19:36  geoff
+ * If the DICTIONARY environment variable is set, derive the default
+ * personal-dictionary name from it.
+ *
  * Revision 1.131  1995/01/08  23:23:39  geoff
  * Support variable hashfile suffixes for DOS purposes.  Report all the
  * new configuration variables in the -vv switch.  Do some better error
@@ -260,9 +267,18 @@ int main (argc, argv)
 	    (void) strcpy (hashname, p);
 	else
 	    (void) sprintf (hashname, "%s/%s", LIBDIR, p);
+	(void) strcpy (libdictname, p);
 	p = rindex (p, '.');
 	if (p == NULL  ||  strcmp (p, HASHSUFFIX) != 0)
 	    (void) strcat (hashname, HASHSUFFIX);
+	LibDict = rindex (libdictname, '/');
+	if (LibDict != NULL)
+	    LibDict++;
+	else
+	    LibDict = libdictname;
+	p = rindex (libdictname, '.');
+	if (p != NULL)
+	    *p = '\0';
 	}
     else
 	(void) sprintf (hashname, "%s/%s", LIBDIR, DEFHASH);
@@ -646,9 +662,12 @@ int main (argc, argv)
 		    *p = '\0';	/* Don't want ext. in LibDict */
 		else
 		    (void) strcat (hashname, HASHSUFFIX);
-		p = rindex (LibDict, '/');
-		if (p != NULL)
-		    LibDict = p + 1;
+		if (LibDict != NULL)
+		    {
+		    p = rindex (LibDict, '/');
+		    if (p != NULL)
+			LibDict = p + 1;
+		    }
 		break;
 	    case 'V':		/* Display 8-bit characters as M-xxx */
 		if (arglen > 2)
@@ -849,9 +868,6 @@ static void update_file (filename, statbuf)
     {
     char		bakfile[MAXPATHLEN];
     int			c;
-#ifdef TRUNCATEBAK
-    int			maxlen;
-#endif /* TRUNCATEBAK */
     char *		pathtail;
 
     if ((infile = fopen (tempfile, "r")) == NULL)
@@ -866,7 +882,6 @@ static void update_file (filename, statbuf)
     bakfile[sizeof bakfile - 1] = '\0';
     if (strcmp(BAKEXT, filename + strlen(filename) - sizeof BAKEXT - 1) != 0)
 	{
-	maxlen = MAXNAMLEN - strlen (BAKEXT);
 	pathtail = rindex (bakfile, '/');
 	if (pathtail == NULL)
 	    pathtail = bakfile;
