@@ -1,5 +1,5 @@
 /*
- * $Id: msgs.h,v 1.30 1994/10/25 05:46:40 geoff Exp $
+ * $Id: msgs.h,v 1.31 1994/12/27 23:08:57 geoff Exp $
  *
  * Copyright 1992, 1993, Geoff Kuenning, Granada Hills, CA
  * All rights reserved.
@@ -65,6 +65,9 @@
 
 /*
  * $Log: msgs.h,v $
+ * Revision 1.31  1994/12/27  23:08:57  geoff
+ * Add a message to be issued if a word contains illegal characters.
+ *
  * Revision 1.30  1994/10/25  05:46:40  geoff
  * Improve a couple of error messages relating to affix flags.
  *
@@ -217,6 +220,7 @@
  * The following strings are used in makedent.c:
  */
 #define MAKEDENT_C_NO_WORD_SPACE "\r\nCouldn't allocate space for word '%s'\r\n"
+#define MAKEDENT_C_BAD_WORD_CHAR "\r\nWord '%s' contains illegal characters\r\n"
 
 /*
  * The following strings are used in parse.y:
