@@ -1,7 +1,6 @@
-/* -*- Mode:Text -*- */
 #ifndef lint
 static char Rcs_Id[] =
-    "$Id: lookup.c,v 1.29 91/09/11 23:22:51 geoff Exp $";
+    "$Id: lookup.c,v 1.42 1995/01/08 23:23:42 geoff Exp $";
 #endif
 
 /*
@@ -9,128 +8,67 @@ static char Rcs_Id[] =
  *
  * Pace Willisson, 1983
  *
- * Copyright 1987, 1988, 1989, by Geoff Kuenning, Manhattan Beach, CA
- * Permission for non-profit use is hereby granted.
- * All other rights reserved.
- * See "version.h" for a more complete copyright notice.
+ * Copyright 1987, 1988, 1989, 1992, 1993, Geoff Kuenning, Granada Hills, CA
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ *
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * 3. All modifications to the source code must be clearly marked as
+ *    such.  Binary redistributions based on modified source code
+ *    must be clearly marked as modified versions in the documentation
+ *    and/or other materials provided with the distribution.
+ * 4. All advertising materials mentioning features or use of this software
+ *    must display the following acknowledgment:
+ *      This product includes software developed by Geoff Kuenning and
+ *      other unpaid contributors.
+ * 5. The name of Geoff Kuenning may not be used to endorse or promote
+ *    products derived from this software without specific prior
+ *    written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY GEOFF KUENNING AND CONTRIBUTORS ``AS IS'' AND
+ * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED.  IN NO EVENT SHALL GEOFF KUENNING OR CONTRIBUTORS BE LIABLE
+ * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+ * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
+ * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+ * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+ * SUCH DAMAGE.
  */
 
 /*
- * $Log:	lookup.c,v $
- * Revision 1.29  91/09/11  23:22:51  geoff
- * Make sure to allocate enough space in the flag tables to allow for
- * string characters.  Make sure that "viazero" is set even if an affix
- * entry is empty.
- * 
- * Revision 1.28  91/07/11  19:52:17  geoff
- * Remove the include of stdio.h, since ispell.h now does this.
- * 
- * Revision 1.27  91/07/05  19:51:47  geoff
- * Fix some lint complaints.
- * 
- * Revision 1.26  91/05/27  21:48:03  geoff
- * Fix a bug in reading in null-affix prefix flags.  Add support for
- * reading the string character type table from the hash file.
- * 
- * Revision 1.25  91/02/26  23:24:04  geoff
- * If the options are no good, abort the run
- * 
- * Revision 1.24  90/12/31  00:59:22  geoff
- * Reformat to follow a consistent convention throughout ispell
- * 
- * Revision 1.23  90/04/26  22:44:11  geoff
- * Add the canonicalize parameter to the call to ichartostr.
- * 
- * Revision 1.22  90/04/17  15:33:08  geoff
- * Use explicit masking to prevent sign extension when checking the
- * magic number in the hash header.  Fix a place where the affix length
- * was being set to null when it should have been the affix ponter.
- * 
- * Revision 1.21  89/12/27  03:18:06  geoff
- * Move all messages to msgs.h so they can be reconfigured
- * 
- * Revision 1.20  89/06/09  15:55:12  geoff
- * Add support for the internal "character" type, ichar_t.
- * 
- * Revision 1.19  89/04/28  01:11:51  geoff
- * Change Header to Id;  nobody cares about my pathnames.
- * 
- * Revision 1.18  89/04/03  01:56:54  geoff
- * Fix a bunch of lint complaints.  Add support for keeping the compilation
- * options separate from the magic number.
- * 
- * Revision 1.17  88/12/26  02:30:25  geoff
- * Add a copyright notice.
- * 
- * Revision 1.16  88/11/16  02:19:31  geoff
- * Improve the quality of the error message issued when linit() fails to
- * initialize the hash table.
- * 
- * Revision 1.15  88/04/30  22:14:31  geoff
- * Fix some lint complaints.
- * 
- * Revision 1.14  88/03/27  01:01:44  geoff
- * Add a missing #ifdef on CAPITALIZATION
- * 
- * Revision 1.13  88/02/20  23:13:14  geoff
- * Many changes to support the new capitalization handling data structures.
- * 
- * Revision 1.12  87/09/30  23:31:04  geoff
- * Move some globals to ispell.h.
- * 
- * Revision 1.11  87/07/20  23:22:58  geoff
- * Enhance tinit to honor nodictflag and to read in the language tables.
- * 
- * Revision 1.10  87/04/19  22:53:08  geoff
- * Make hashheader a global, and rearrange the includes of ispell.h
- * and config.h.
- * 
- * Revision 1.9  87/03/26  00:30:40  geoff
- * Integrate Rich Salz's changes/improvements
- * 
- * Revision 1.8  87/03/10  23:33:03  geoff
- * Add code to exit gracefully if there isn't space for the hash table,
- * instead of just core dumping.
- * 
- * Revision 1.7  87/03/08  20:31:06  geoff
- * Accept an empty hash file as legal, and create a dummy null table
- * in that case.  Add the "dotree" argument to lookup.
- * 
- * Revision 1.6  87/03/05  22:56:02  geoff
- * Only set lastdent if something is found
- * 
- * Revision 1.5  87/03/01  00:56:59  geoff
- * Get rid of the cflag stuff,  it's now wrong.  Add code to convert all
- * the indexes in the hash table into pointers, so the loops don't have to.
- * Modify the rest of the code to expect pointers.  Be sure to set lastdent
- * if treelookup succeeds.
- * 
- * Revision 1.4  87/02/28  14:58:32  geoff
- * If lookup fails, try treelookup instead.  Also, if cflag is set, don't
- * read in the hash database.
- * 
- * Revision 1.3  87/02/26  00:26:59  geoff
- * Integrate McQueer's enhancements into the main branch
- * 
- * Revision 1.2  87/01/17  13:12:00  geoff
- * Add RCS ID keywords
- * 
+ * $Log: lookup.c,v $
+ * Revision 1.42  1995/01/08  23:23:42  geoff
+ * Support MSDOS_BINARY_OPEN when opening the hash file to read it in.
+ *
+ * Revision 1.41  1994/01/25  07:11:51  geoff
+ * Get rid of all old RCS log lines in preparation for the 3.1 release.
+ *
  */
 
 #include "config.h"
 #include "ispell.h"
+#include "proto.h"
 #include "msgs.h"
 
-
-struct dent *	treelookup ();
-
-extern char *	calloc ();
-extern char *	malloc ();
-extern long	lseek ();
+int		linit P ((void));
+#ifdef INDEXDUMP
+static void	dumpindex P ((struct flagptr * indexp, int depth));
+#endif /* INDEXDUMP */
+struct dent *	lookup P ((ichar_t * word, int dotree));
 
 static		inited = 0;
 
-linit ()
+int linit ()
     {
     int			hashfd;
     register int	i;
@@ -144,7 +82,7 @@ linit ()
     if (inited)
 	return 0;
 
-    if ((hashfd = open (hashname, 0)) < 0)
+    if ((hashfd = open (hashname, 0 | MSDOS_BINARY_OPEN)) < 0)
 	{
 	(void) fprintf (stderr, CANT_OPEN, hashname);
 	return (-1);
@@ -159,13 +97,22 @@ linit ()
 	    (void) fprintf (stderr, LOOKUP_C_NULL_HASH, hashname);
 	else
 	    (void) fprintf (stderr,
-	      LOOKUP_C_SHORT_HASH (hashname, hashsize, sizeof hashheader));
+	      LOOKUP_C_SHORT_HASH (hashname, hashsize,
+	        (int) sizeof hashheader));
 	return (-1);
 	}
-    else if ((hashheader.magic & 0xFFFFL) != (long) MAGIC)
+    else if (hashheader.magic != MAGIC)
 	{
 	(void) fprintf (stderr,
-	  LOOKUP_C_BAD_MAGIC (hashname, MAGIC, hashheader.magic));
+	  LOOKUP_C_BAD_MAGIC (hashname, (unsigned int) MAGIC,
+	    (unsigned int) hashheader.magic));
+	return (-1);
+	}
+    else if (hashheader.magic2 != MAGIC)
+	{
+	(void) fprintf (stderr,
+	  LOOKUP_C_BAD_MAGIC2 (hashname, (unsigned int) MAGIC,
+	    (unsigned int) hashheader.magic2));
 	return (-1);
 	}
     else if (hashheader.compileoptions != COMPILEOPTIONS
@@ -173,9 +120,9 @@ linit ()
       ||  hashheader.maxstringcharlen != MAXSTRINGCHARLEN)
 	{
 	(void) fprintf (stderr,
-	  LOOKUP_C_BAD_OPTIONS (hashheader.compileoptions,
+	  LOOKUP_C_BAD_OPTIONS ((unsigned int) hashheader.compileoptions,
 	    hashheader.maxstringchars, hashheader.maxstringcharlen,
-	  COMPILEOPTIONS, MAXSTRINGCHARS, MAXSTRINGCHARLEN));
+	    (unsigned int) COMPILEOPTIONS, MAXSTRINGCHARS, MAXSTRINGCHARLEN));
 	return (-1);
 	}
     if (nodictflag)
@@ -302,7 +249,7 @@ linit ()
 	    cp = entry->affix + entry->affl - 1;
 	    ind = &sflagindex[*cp];
 	    viazero = 0;
-	    while (ind->numents == 0  &&  ind->pu.ent != NULL)
+	    while (ind->numents == 0  &&  ind->pu.fp != NULL)
 		{
 		if (cp == entry->affix)
 		    {
@@ -336,8 +283,9 @@ linit ()
 	    entry = ind->pu.ent - 1; /* -1 is for entry++ in loop */
 	    i = numsflags - (entry - sflaglist);
 	    ind->pu.fp =
-	      (struct flagptr *) calloc (SET_SIZE + MAXSTRINGCHARS,
-	        sizeof (struct flagptr));
+	      (struct flagptr *)
+		calloc ((unsigned) (SET_SIZE + hashheader.nstrchars),
+		  sizeof (struct flagptr));
 	    if (ind->pu.fp == NULL)
 		{
 		(void) fprintf (stderr, LOOKUP_C_NO_LANG_SPACE);
@@ -362,8 +310,9 @@ linit ()
 	else
 	    {
 	    cp = entry->affix;
-	    ind = &pflagindex[*cp];
-	    while (ind->numents == 0  &&  ind->pu.ent != NULL)
+	    ind = &pflagindex[*cp++];
+	    viazero = 0;
+	    while (ind->numents == 0  &&  ind->pu.fp != NULL)
 		{
 		if (*cp == 0)
 		    {
@@ -397,7 +346,7 @@ linit ()
 	    entry = ind->pu.ent - 1; /* -1 is for entry++ in loop */
 	    i = numpflags - (entry - pflaglist);
 	    ind->pu.fp =
-	      (struct flagptr *) calloc (SET_SIZE + MAXSTRINGCHARS,
+	      (struct flagptr *) calloc (SET_SIZE + hashheader.nstrchars,
 	        sizeof (struct flagptr));
 	    if (ind->pu.fp == NULL)
 		{
@@ -430,6 +379,8 @@ linit ()
 	    {
 	    chartypes[i].name = &hashstrings[nextchar];
 	    nextchar += strlen (chartypes[i].name) + 1;
+	    chartypes[i].deformatter = &hashstrings[nextchar];
+	    nextchar += strlen (chartypes[i].deformatter) + 1;
 	    chartypes[i].suffixes = &hashstrings[nextchar];
 	    while (hashstrings[nextchar] != '\0')
 		nextchar += strlen (&hashstrings[nextchar]) + 1;
@@ -441,20 +392,22 @@ linit ()
     }
 
 #ifdef INDEXDUMP
-int dumpindex (indexp, depth)
+static void dumpindex (indexp, depth)
     register struct flagptr *	indexp;
     register int		depth;
     {
     register int		i;
     int				j;
+    int				k;
+    char			stripbuf[INPUTWORDLEN + 4 * MAXAFFIXLEN + 4];
 
-    for (i = 0;  i < SET_SIZE;  i++, indexp++)
+    for (i = 0;  i < SET_SIZE + hashheader.nstrchars;  i++, indexp++)
 	{
 	if (indexp->numents == 0  &&  indexp->pu.fp != NULL)
 	    {
 	    for (j = depth;  --j >= 0;  )
 		(void) putc (' ', stderr);
-	    if (i >= ' '  &&  i < '~')
+	    if (i >= ' '  &&  i <= '~')
 		(void) putc (i, stderr);
 	    else
 		(void) fprintf (stderr, "0x%x", i);
@@ -465,20 +418,30 @@ int dumpindex (indexp, depth)
 	    {
 	    for (j = depth;  --j >= 0;  )
 		(void) putc (' ', stderr);
-	    if (i >= ' '  &&  i < '~')
+	    if (i >= ' '  &&  i <= '~')
 		(void) putc (i, stderr);
 	    else
 		(void) fprintf (stderr, "0x%x", i);
-	    if (indexp->pu.ent->stripl)
-		(void) fprintf (stderr, " -> entry %d (-%s,%s), %d entries\n",
-		  indexp->pu.ent - sflaglist,
-		  indexp->pu.ent->strip,
-		  indexp->pu.ent->affl ? indexp->pu.ent->affix : "-",
-		  indexp->numents);
-	    else
-		(void) fprintf (stderr, " -> entry %d (%s), %d entries\n",
-		  indexp->pu.ent - sflaglist,
-		  indexp->pu.ent->affix, indexp->numents);
+	    (void) fprintf (stderr, " -> %d entries\n", indexp->numents);
+	    for (k = 0;  k < indexp->numents;  k++)
+		{
+		for (j = depth;  --j >= 0;  )
+		    (void) putc (' ', stderr);
+		if (indexp->pu.ent[k].stripl)
+		    {
+		    (void) ichartostr (stripbuf, indexp->pu.ent[k].strip,
+		      sizeof stripbuf, 1);
+		    (void) fprintf (stderr, "     entry %d (-%s,%s)\n",
+		      &indexp->pu.ent[k] - sflaglist,
+		      stripbuf,
+		      indexp->pu.ent[k].affl
+			? ichartosstr (indexp->pu.ent[k].affix, 1) : "-");
+		    }
+		else
+		    (void) fprintf (stderr, "     entry %d (%s)\n",
+		      &indexp->pu.ent[k] - sflaglist,
+		      ichartosstr (indexp->pu.ent[k].affix, 1));
+		}
 	    }
 	}
     }
@@ -487,20 +450,22 @@ int dumpindex (indexp, depth)
 /* n is length of s */
 struct dent * lookup (s, dotree)
     register ichar_t *		s;
+    int				dotree;
     {
     register struct dent *	dp;
     register char *		s1;
     char			schar[INPUTWORDLEN + MAXAFFIXLEN];
 
     dp = &hashtbl[hash (s, hashsize)];
-    ichartostr (schar, s, 1);
+    if (ichartostr (schar, s, sizeof schar, 1))
+	(void) fprintf (stderr, WORD_TOO_LONG (schar));
     for (  ;  dp != NULL;  dp = dp->next)
 	{
 	/* quick strcmp, but only for equality */
 	s1 = dp->word;
 	if (s1  &&  s1[0] == schar[0]  &&  strcmp (s1 + 1, schar + 1) == 0)
 	    return dp;
-#ifdef CAPITALIZATION
+#ifndef NO_CAPITALIZATION_SUPPORT
 	while (dp->flagfield & MOREVARIANTS)	/* Skip variations */
 	    dp = dp->next;
 #endif
