@@ -1,6 +1,6 @@
 #ifndef lint
 static char Rcs_Id[] =
-	"$Id: makedent.c,v 1.44 1994/10/25 05:46:20 geoff Exp $";
+	"$Id: makedent.c,v 1.45 1994/12/27 23:08:52 geoff Exp $";
 #endif
 
 /*
@@ -43,6 +43,11 @@ static char Rcs_Id[] =
 
 /*
  * $Log: makedent.c,v $
+ * Revision 1.45  1994/12/27  23:08:52  geoff
+ * Add code to makedent to reject words that contain non-word characters.
+ * This helps protect people who use ISO 8-bit characters when ispell
+ * isn't configured for that option.
+ *
  * Revision 1.44  1994/10/25  05:46:20  geoff
  * Fix some incorrect declarations in the lint versions of some routines.
  *
@@ -116,6 +121,7 @@ int makedent (lbuf, lbuflen, d)
     struct dent *	d;
     {
     ichar_t		ibuf[INPUTWORDLEN + MAXAFFIXLEN];
+    ichar_t *		ip;
     char *		p;
     int			bit;
     int			len;
@@ -146,6 +152,22 @@ int makedent (lbuf, lbuflen, d)
 	(void) fprintf (stderr, WORD_TOO_LONG (lbuf));
 	return (-1);
 	}
+    /*
+    ** Make sure the word is well-formed (contains only legal characters).
+    */
+    for (ip = ibuf;  *ip != 0;  ip++)
+	{
+	if (!iswordch (*ip))
+	    {
+	    /* Boundary characters are legal as long as they're not at edges */
+	    if (!isboundarych (*ip)
+	      ||  ip == ibuf  ||  ip[1] == 0)
+		{
+		(void) fprintf (stderr, MAKEDENT_C_BAD_WORD_CHAR, lbuf);
+		return -1;
+		}
+	    }
+	}
     len = strlen (lbuf);
 #ifndef NO_CAPITALIZATION_SUPPORT
     /*
