@@ -1,6 +1,6 @@
 #ifndef lint
 static char Rcs_Id[] =
-    "$Id: term.c,v 1.46 1994/01/25 07:12:11 geoff Exp $";
+    "$Id: term.c,v 1.48 1994/10/25 05:46:11 geoff Exp $";
 #endif
 
 /*
@@ -47,6 +47,14 @@ static char Rcs_Id[] =
 
 /*
  * $Log: term.c,v $
+ * Revision 1.48  1994/10/25  05:46:11  geoff
+ * Fix a couple of places where ifdefs were omitted, though apparently
+ * harmlessly.
+ *
+ * Revision 1.47  1994/09/01  06:06:32  geoff
+ * Change erasechar/killchar to uerasechar/ukillchar to avoid
+ * shared-library problems on HP systems.
+ *
  * Revision 1.46  1994/01/25  07:12:11  geoff
  * Get rid of all old RCS log lines in preparation for the 3.1 release.
  *
@@ -250,8 +258,8 @@ retry:
     sbuf.c_cc[VTIME] = 1;
     (void) ioctl (0, TCSETAW, (char *) &sbuf);
 
-    erasechar = osbuf.c_cc[VERASE];
-    killchar = osbuf.c_cc[VKILL];
+    uerasechar = osbuf.c_cc[VERASE];
+    ukillchar = osbuf.c_cc[VKILL];
 
 #endif
 
@@ -294,8 +302,8 @@ retry:
     sbuf.sg_flags |= TERM_MODE;
     (void) ioctl (0, TIOCSETP, (char *) &sbuf);
 
-    erasechar = sbuf.sg_erase;
-    killchar = sbuf.sg_kill;
+    uerasechar = sbuf.sg_erase;
+    ukillchar = sbuf.sg_kill;
 
 #ifdef TIOCSLTC
     ltc = oltc;
@@ -430,7 +438,9 @@ int shellescape	(buf)
     (void) ioctl (0, TCSETAW, (char *) &osbuf);
 #else
     (void) ioctl (0, TIOCSETP, (char *) &osbuf);
+#ifdef TIOCSLTC
     (void) ioctl (0, TIOCSLTC, (char *) &oltc);
+#endif /* TIOCSLTC */
 #endif
     (void) signal (SIGINT, oldint);
     (void) signal (SIGTERM, oldterm);
@@ -474,7 +484,9 @@ int shellescape	(buf)
     (void) ioctl (0, TCSETAW, (char *) &sbuf);
 #else
     (void) ioctl (0, TIOCSETP, (char *) &sbuf);
+#ifdef TIOCSLTC
     (void) ioctl (0, TIOCSLTC, (char *) &ltc);
+#endif /* TIOCSLTC */
 #endif
     if (termstat)
 	{
